Name:          hazelcast
Version:       3.2.2
Release:       2%{?dist}
Summary:       Hazelcast CE In-Memory DataGrid
License:       ASL 2.0
URL:           http://www.hazelcast.com/
Source0:       https://github.com/hazelcast/hazelcast/archive/v%{version}.tar.gz

%if %{fedora} >= 21
BuildRequires: mvn(log4j:log4j:1.2.17)
%else
BuildRequires: mvn(log4j:log4j)
%endif
BuildRequires: mvn(net.sourceforge.findbugs:annotations)
BuildRequires: mvn(org.apache.tomcat:tomcat-servlet-api)
# use groovy-all 2.1.8
BuildRequires: mvn(org.codehaus.groovy:groovy)
BuildRequires: mvn(org.hibernate:hibernate-core)
BuildRequires: mvn(org.jboss.spec.javax.resource:jboss-connector-api_1.6_spec)
BuildRequires: mvn(org.jruby:shared)
%if %{fedora} >= 20
BuildRequires: mvn(org.jruby:jruby)
%else
BuildRequires: mvn(org.jruby:shared)
%endif
BuildRequires: mvn(org.osgi:org.osgi.core)
BuildRequires: mvn(org.slf4j:slf4j-api)
BuildRequires: glassfish-jsp-api

%if 0
# hazelcast-spring
BuildRequires: hibernate3
BuildRequires: mvn(javax.annotation:jsr250-api)
BuildRequires: mvn(org.springframework:spring-beans)
BuildRequires: mvn(org.springframework:spring-context)
BuildRequires: mvn(org.springframework:spring-core)
BuildRequires: mvn(org.mongodb:mongo-java-driver) >= 2.7.3
# Unavailable dep
BuildRequires: mvn(org.springframework.data:spring-data-mongodb) >= 1.0.1.RELEASE

# hazelcast-spring test deps
BuildRequires: mvn(org.springframework:spring-tx)
BuildRequires: mvn(org.springframework:spring-test)

# test deps
BuildRequires: mvn(javassist:javassist)
BuildRequires: mvn(org.hsqldb:hsqldb)
#BuildRequires: mvn(org.eclipse.jetty:jetty-jsp)
BuildRequires: mvn(org.eclipse.jetty:jetty-webapp)
BuildRequires: mvn(org.slf4j:slf4j-simple)
%endif

BuildRequires: mvn(junit:junit)
BuildRequires: mvn(org.mockito:mockito-core)

BuildRequires: maven-local
BuildRequires: maven-dependency-plugin
BuildRequires: maven-assembly-plugin
BuildRequires: maven-antrun-plugin
BuildRequires: maven-plugin-bundle
#BuildRequires: maven-rar-plugin
BuildRequires: maven-source-plugin

BuildArch:     noarch

%description
Hazelcast CE is an open source highly scalable data distribution platform.
Hazelcast allows you to easily share and partition your data across your
cluster.

%package client
Summary:       Hazelcast Client

%description client
Hazelcast Client enables you to do all Hazelcast
operations without being a member of the cluster.

%package cloud
Summary:       Hazelcast EC2 Auto Discovery

%description cloud
Hazelcast EC2 Auto Discovery.

%package hibernate
Summary:       Integration of Hazelcast with Hibernate 3
Provides:      %{name}-hibernate3 = %{version}-%{release}
Obsoletes:     %{name}-hibernate3 < %{version}-%{release}

%description hibernate
Hazelcast second level cache provider for Hibernate 3.

%package ra
Summary:       Hazelcast Resource Adapter
Requires:      %{name} = %{version}-%{release}

%description ra
Hazelcast Resource Adapter.

%if 0
%package spring
Summary:       Integration of Hazelcast with Spring

%description spring
Hazelcast Spring cache provider.
%endif

%package wm
Summary:       Hazelcast WebFilter

%description wm
Hazelcast dynamic HTTP session clustering.

%package javadoc
Summary:       Javadoc for %{name}

%description javadoc
This package contains javadoc for %{name}.

%prep
%setup -q -n %{name}-%{version}
find . -name "*.bat" -delete
find . -name "*.class" -delete
find . -name "*.jar" -delete
find . -name "*.rar" -delete
find . -name "*.war" -delete

%pom_remove_plugin :findbugs-maven-plugin

for p in %{name} \
 %{name}-client \
 %{name}-cloud \
 %{name}-hibernate \
 %{name}-ra/hazelcast-jca \
 %{name}-spring \
 %{name}-wm; do
%pom_remove_plugin :maven-source-plugin ${p}
%pom_remove_plugin :animal-sniffer-maven-plugin ${p}
done

%pom_remove_plugin :jetty-maven-plugin %{name}-wm

%pom_disable_module %{name}-documentation
%pom_disable_module hazelcast-hibernate3 %{name}-hibernate
%pom_disable_module hazelcast-jca-rar %{name}-ra
# requires org.springframework.data:spring-data-mongodb
%pom_disable_module %{name}-spring

%pom_xpath_remove "pom:project/pom:build/pom:plugins/pom:plugin[pom:artifactId='maven-bundle-plugin']/pom:executions/pom:execution/pom:configuration/pom:instructions/pom:Import-Package" %{name}-all
%pom_xpath_inject "pom:project/pom:build/pom:plugins/pom:plugin[pom:artifactId='maven-bundle-plugin']/pom:executions/pom:execution/pom:configuration/pom:instructions" "
<Import-Package>
    !junit.framework,
    !org.junit,
    !org.mockito,
    org.apache.log4j;resolution:=optional,
    org.apache.log4j.*;resolution:=optional,
    org.slf4j;resolution:=optional,
    org.hibernate;resolution:=optional,
    org.hibernate.*;resolution:=optional,
    *
</Import-Package>" %{name}-all

%pom_remove_plugin :maven-shade-plugin %{name}-all
sed -i 's|<artifactId>hazelcast-hibernate3</artifactId>|<artifactId>hazelcast-hibernate4</artifactId>|' %{name}-all/pom.xml

%pom_xpath_set "pom:dependencies/pom:dependency[pom:groupId = 'org.mockito' ]/pom:artifactId" mockito-core

%if %{fedora} >= 20
%pom_xpath_set "pom:project/pom:dependencies/pom:dependency[pom:groupId = 'org.jruby' ]/pom:artifactId" jruby %{name}
%else
%pom_xpath_set "pom:project/pom:dependencies/pom:dependency[pom:groupId = 'org.jruby' ]/pom:artifactId" shared %{name}
%endif

%pom_xpath_set "pom:project/pom:dependencies/pom:dependency[pom:groupId = 'org.codehaus.groovy' ]/pom:artifactId" groovy %{name}

%pom_remove_dep org.apache.geronimo.specs:geronimo-j2ee-connector_1.5_spec %{name}-ra/%{name}-jca
%pom_add_dep org.jboss.spec.javax.resource:jboss-connector-api_1.6_spec::provided %{name}-ra/%{name}-jca
%pom_remove_dep org.jboss.spec:jboss-javaee-6.0 %{name}-ra/%{name}-jca
%pom_remove_dep org.jboss.arquillian.extension:arquillian-transaction-bom %{name}-ra/%{name}-jca
%pom_remove_dep org.jboss.arquillian:arquillian-bom %{name}-ra/%{name}-jca
%pom_xpath_remove "pom:project/pom:dependencies/pom:dependency[pom:scope='test']" %{name}-ra/%{name}-jca

%pom_remove_dep javax.servlet:javax.servlet-api %{name}-wm
%pom_add_dep org.apache.tomcat:tomcat-servlet-api::provided %{name}-wm

%pom_remove_dep org.eclipse.jetty:jetty-jsp %{name}-wm
%pom_add_dep org.glassfish.web:javax.servlet.jsp::test %{name}-wm

cp -p src/main/resources/apache-v2-license.txt license.txt
cp -p src/main/resources/notice.txt .

sed -i 's|../lib/hazelcast-${project.version}.jar|%{_javadir}/%{name}/%{name}.jar|' \
 %{name}/src/main/resources/*.sh
sed -i 's|../lib/hazelcast-client-${project.version}.jar|%{_javadir}/%{name}/%{name}-client.jar|' \
%{name}/src/main/resources/client.sh

for m in client \
  hibernate \
  spring \
  wm; do
%pom_xpath_remove "pom:project/pom:dependencies/pom:dependency[pom:scope='test']" %{name}-${m}
done
rm -rf hazelcast*/src/test/java/*

%if %{fedora} >= 21
sed -i "s|<log4j.version>1.2.12</log4j.version>|<log4j.version>1.2.17</log4j.version>|" pom.xml
%endif

#%%mvn_package ":%%{name}-all" %%{name}
%mvn_package ":%{name}-root" %{name}
%mvn_package ":%{name}-hibernate*" %{name}-hibernate
%mvn_package ":%{name}-jca" %{name}-ra

%build

# takes too much time and @ random fails
# e.g.
# [INFO] hazelcast ......................................... SUCCESS [49:00.842s]
# Tests in error: 
#  putIfAbsentWithTtl(com.hazelcast.client.HazelcastClientMapTest): No cluster member available to connect
#  testNoClusterAfterStart(com.hazelcast.client.HazelcastClientClusterTest): Unexpected exception, expected<com.hazelcast.client.NoMemberAvailableException> but was<java.lang.RuntimeException>

%mvn_build -f -s

%install
%mvn_install

%files -f .mfiles-%{name}
%dir %{_javadir}/%{name}
%doc README.md
%license license.txt notice.txt

%files client -f .mfiles-%{name}-client
%license license.txt notice.txt

%files cloud -f .mfiles-%{name}-cloud
%license license.txt notice.txt

%files hibernate -f .mfiles-%{name}-hibernate
%license license.txt notice.txt

%files ra -f .mfiles-%{name}-ra
%license license.txt notice.txt

%if 0
%files spring -f .mfiles-%{name}-spring
%license license.txt notice.txt
%endif

%files wm -f .mfiles-%{name}-wm
%license license.txt notice.txt

%files javadoc -f .mfiles-javadoc
%license license.txt notice.txt

%changelog
* Tue Jan 20 2015 gil cattaneo <puntogil@libero.it> 3.2.2-2
- introduce license macro

* Wed Jun 11 2014 gil cattaneo <puntogil@libero.it> 3.2.2-1
- update to 3.2.2

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.6.3-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Wed Oct 02 2013 gil cattaneo <puntogil@libero.it> 2.6.3-1
- update to 2.6.3

* Fri Aug 30 2013 gil cattaneo <puntogil@libero.it> 2.6.2-1
- update to 2.6.2

* Wed Jun 05 2013 gil cattaneo <puntogil@libero.it> 2.6-1
- initial rpm
